{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Unaligned to aligned BAM",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#align.cwl/bam"
                },
                {
                    "type": "string",
                    "id": "#align.cwl/readgroup"
                },
                {
                    "type": "string",
                    "id": "#align.cwl/reference"
                }
            ],
            "steps": [
                {
                    "run": "#align_and_tag.cwl",
                    "in": [
                        {
                            "source": "#align.cwl/bam",
                            "id": "#align.cwl/align_and_tag/bam"
                        },
                        {
                            "source": "#align.cwl/readgroup",
                            "id": "#align.cwl/align_and_tag/readgroup"
                        },
                        {
                            "source": "#align.cwl/reference",
                            "id": "#align.cwl/align_and_tag/reference"
                        }
                    ],
                    "out": [
                        "#align.cwl/align_and_tag/aligned_bam"
                    ],
                    "id": "#align.cwl/align_and_tag"
                }
            ],
            "id": "#align.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#align.cwl/align_and_tag/aligned_bam",
                    "id": "#align.cwl/tagged_bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "align with bwa_mem and tag",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/alignment_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 16000
                }
            ],
            "stdout": "refAlign.bam",
            "arguments": [
                {
                    "position": 4,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#align_and_tag.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#align_and_tag.cwl/readgroup"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#align_and_tag.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#align_and_tag.cwl/aligned_bam",
                    "outputBinding": {
                        "glob": "refAlign.bam"
                    }
                }
            ],
            "id": "#align_and_tag.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "apply BQSR",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "PrintReads"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/Final.bam"
                },
                "-preserveQ",
                "6",
                "-SQQ",
                "10",
                "-SQQ",
                "20",
                "-SQQ",
                "30",
                "-nct",
                "8",
                "--disable_indel_quals"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#apply_bqsr.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-BQSR",
                        "position": 3
                    },
                    "id": "#apply_bqsr.cwl/bqsr_table"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#apply_bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "Final.bam"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#apply_bqsr.cwl/bqsr_bam"
                }
            ],
            "id": "#apply_bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "BAM to CRAM conversion",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-C"
            ],
            "stdout": "final.cram",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bam_to_cram.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#bam_to_cram.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bam_to_cram.cwl/cram",
                    "outputBinding": {
                        "glob": "final.cram"
                    }
                }
            ],
            "id": "#bam_to_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "create BQSR table",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "BaseRecalibrator"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/bqsr.table"
                },
                "--preserve_qscores_less_than",
                "6",
                "--disable_auto_index_creation_and_locking_when_reading_rods",
                "--disable_bam_indexing",
                "-dfrac",
                ".1",
                "-nct",
                "4"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bqsr.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "default": [
                        "chr1",
                        "chr2",
                        "chr3",
                        "chr4",
                        "chr5",
                        "chr6",
                        "chr7",
                        "chr8",
                        "chr9",
                        "chr10",
                        "chr11",
                        "chr12",
                        "chr13",
                        "chr14",
                        "chr15",
                        "chr16",
                        "chr17",
                        "chr18",
                        "chr19",
                        "chr20",
                        "chr21",
                        "chr22"
                    ],
                    "id": "#bqsr.cwl/intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-knownSites",
                            "position": 4
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bqsr.cwl/known_sites"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 2
                    },
                    "id": "#bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bqsr.table"
                    },
                    "id": "#bqsr.cwl/bqsr_table"
                }
            ],
            "id": "#bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "downsample unaligned BAM",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/picard/picard.jar",
                "DownsampleSam"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/downsampled.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT="
                    },
                    "id": "#downsample.cwl/bam"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "prefix": "PROBABILITY="
                    },
                    "id": "#downsample.cwl/probability"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#downsample.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "downsampled.bam"
                    },
                    "id": "#downsample.cwl/downsampled_bam"
                }
            ],
            "id": "#downsample.cwl"
        },
        {
            "class": "Workflow",
            "label": "downsample unaligned BAM and align",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/bams"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/dbsnp"
                },
                {
                    "type": "float",
                    "id": "#main/downsample_probability"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mills"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/readgroups"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/align_workflow/final_cram",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#main/cram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/align_workflow/mark_duplicates_metrics_file",
                    "id": "#main/mark_duplicates_metrics_file"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#main/downsample/downsampled_bam",
                            "id": "#main/align_workflow/bams"
                        },
                        {
                            "source": "#main/dbsnp",
                            "id": "#main/align_workflow/dbsnp"
                        },
                        {
                            "source": "#main/known_indels",
                            "id": "#main/align_workflow/known_indels"
                        },
                        {
                            "source": "#main/mills",
                            "id": "#main/align_workflow/mills"
                        },
                        {
                            "source": "#main/readgroups",
                            "id": "#main/align_workflow/readgroups"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/align_workflow/reference"
                        }
                    ],
                    "out": [
                        "#main/align_workflow/final_cram",
                        "#main/align_workflow/mark_duplicates_metrics_file"
                    ],
                    "id": "#main/align_workflow"
                },
                {
                    "scatter": [
                        "#main/downsample/bam"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#downsample.cwl",
                    "in": [
                        {
                            "source": "#main/bams",
                            "id": "#main/downsample/bam"
                        },
                        {
                            "source": "#main/downsample_probability",
                            "id": "#main/downsample/probability"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/downsample/reference"
                        }
                    ],
                    "out": [
                        "#main/downsample/downsampled_bam"
                    ],
                    "id": "#main/downsample"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index cram",
            "arguments": [
                "cp",
                "$(inputs.cram.path)",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                "$(runtime.outdir)/$(inputs.cram.basename).crai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "ln",
                "-s",
                "$(inputs.cram.basename).crai",
                "$(runtime.outdir)/$(inputs.cram.nameroot).crai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_cram.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.basename)"
                    },
                    "id": "#index_cram.cwl/indexed_cram"
                }
            ],
            "id": "#index_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "mark duplicates and sort",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/markduplicates_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 40000
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "position": 3,
                    "valueFrom": "$(runtime.outdir)/MarkedSorted.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#mark_duplicates_and_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mark_dups_metrics.txt"
                    },
                    "id": "#mark_duplicates_and_sort.cwl/metrics_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "MarkedSorted.bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mark_duplicates_and_sort.cwl/sorted_bam"
                }
            ],
            "id": "#mark_duplicates_and_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "merge BAMs",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "merge"
            ],
            "arguments": [
                "AlignedMerged.bam"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#merge.cwl/bams"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "AlignedMerged.bam"
                    },
                    "id": "#merge.cwl/merged_bam"
                }
            ],
            "id": "#merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "sort BAM by name",
            "baseCommand": [
                "/usr/bin/sambamba",
                "sort"
            ],
            "arguments": [
                "-t",
                {
                    "valueFrom": "$(runtime.cores)"
                },
                "-m",
                "12G",
                "-n",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/NameSorted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 13000,
                    "coresMin": 8
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#name_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "NameSorted.bam"
                    },
                    "id": "#name_sort.cwl/name_sorted_bam"
                }
            ],
            "id": "#name_sort.cwl"
        },
        {
            "class": "Workflow",
            "label": "Unaligned BAM to BQSR and VCF",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#workflow.cwl/bams"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#workflow.cwl/bqsr_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl/dbsnp"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl/mills"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#workflow.cwl/readgroups"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl/index_cram/indexed_cram",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#workflow.cwl/final_cram"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl/mark_duplicates_and_sort/metrics_file",
                    "id": "#workflow.cwl/mark_duplicates_metrics_file"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#workflow.cwl/align/bam",
                        "#workflow.cwl/align/readgroup"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#align.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/bams",
                            "id": "#workflow.cwl/align/bam"
                        },
                        {
                            "source": "#workflow.cwl/readgroups",
                            "id": "#workflow.cwl/align/readgroup"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/align/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/align/tagged_bam"
                    ],
                    "id": "#workflow.cwl/align"
                },
                {
                    "run": "#apply_bqsr.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/mark_duplicates_and_sort/sorted_bam",
                            "id": "#workflow.cwl/apply_bqsr/bam"
                        },
                        {
                            "source": "#workflow.cwl/bqsr/bqsr_table",
                            "id": "#workflow.cwl/apply_bqsr/bqsr_table"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/apply_bqsr/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/apply_bqsr/bqsr_bam"
                    ],
                    "id": "#workflow.cwl/apply_bqsr"
                },
                {
                    "run": "#bam_to_cram.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/apply_bqsr/bqsr_bam",
                            "id": "#workflow.cwl/bam_to_cram/bam"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/bam_to_cram/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/bam_to_cram/cram"
                    ],
                    "id": "#workflow.cwl/bam_to_cram"
                },
                {
                    "run": "#bqsr.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/mark_duplicates_and_sort/sorted_bam",
                            "id": "#workflow.cwl/bqsr/bam"
                        },
                        {
                            "source": "#workflow.cwl/bqsr_intervals",
                            "id": "#workflow.cwl/bqsr/intervals"
                        },
                        {
                            "source": [
                                "#workflow.cwl/dbsnp",
                                "#workflow.cwl/mills",
                                "#workflow.cwl/known_indels"
                            ],
                            "id": "#workflow.cwl/bqsr/known_sites"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/bqsr/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/bqsr/bqsr_table"
                    ],
                    "id": "#workflow.cwl/bqsr"
                },
                {
                    "run": "#index_cram.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/bam_to_cram/cram",
                            "id": "#workflow.cwl/index_cram/cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/index_cram/indexed_cram"
                    ],
                    "id": "#workflow.cwl/index_cram"
                },
                {
                    "run": "#mark_duplicates_and_sort.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/name_sort/name_sorted_bam",
                            "id": "#workflow.cwl/mark_duplicates_and_sort/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/mark_duplicates_and_sort/sorted_bam",
                        "#workflow.cwl/mark_duplicates_and_sort/metrics_file"
                    ],
                    "id": "#workflow.cwl/mark_duplicates_and_sort"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/align/tagged_bam",
                            "id": "#workflow.cwl/merge/bams"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/merge/merged_bam"
                    ],
                    "id": "#workflow.cwl/merge"
                },
                {
                    "run": "#name_sort.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/merge/merged_bam",
                            "id": "#workflow.cwl/name_sort/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/name_sort/name_sorted_bam"
                    ],
                    "id": "#workflow.cwl/name_sort"
                }
            ],
            "id": "#workflow.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
